library tencent_im_sdk;

import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:tencent_im_sdk_mobile/tencent_im_sdk_mobile.dart';
import 'package:tencent_im_sdk_platform_interface/tencent_im_sdk_platform_interface.dart';

export 'package:tencent_im_sdk_platform_interface/tencent_im_sdk_platform_interface.dart';

class TIMSdk {
  factory TIMSdk() {
    return _instance;
  }

  TIMSdk._internal() {
    // web
    if (kIsWeb) {
    }

    //mobile
    else if (Platform.isIOS || Platform.isAndroid) {
      _sdk = TIMSdkMobile();
      message = MessageManagerMobile();
      group = GroupManagerMobile();
    }
  }

  static TIMSdk _instance = TIMSdk._internal();

  TIMSdkPlatform? _sdk;
  MessageManagerPlatform? message;
  GroupManagerPlatform? group;

  Stream<TIMEvent> get eventListener {
    return _sdk!.eventListener;
  }

  Future<String> get sdkVersion => _sdk!.sdkVersion;

  Future<void> init({
    required int appId,
    TIMLogLevel logLevel = TIMLogLevel.off,
  }) {
    message!.init();
    group!.init();
    return _sdk!.init(appId: appId, logLevel: logLevel);
  }

  Future<void> unInit() {
    return _sdk!.unInit();
  }

  Future<void> login({
    required String userId,
    required String userSign,
  }) {
    return _sdk!.login(userId: userId, userSign: userSign);
  }

  Future<void> logout() {
    return _sdk!.logout();
  }

  void dispose() {
    message!.dispose();
    group!.dispose();
    _sdk!.dispose();
  }
}
